# 汇报安全问题


哇大佬!! 感谢您能够让钻石铲变得更加安全. 如果您发现了任何安全问题, 请通过以下方式联系我们:

- 电子邮件: security@hscsec.cn

我们会尽快回复您, 并尽快解决问题. 感谢您的支持!

## 安全问题公布指南

按照国际惯例, 我们会在修复了一个经过确认的安全漏洞后, 在90天后会公布这个漏洞的技术细节. 除非它已经被人偷跑和利用

而在漏洞修补版本发布时, 我们只会在更新日志中简要地提及这个漏洞以及危害性, 同时您的联系方式暂时不会被公开

在公开漏洞的技术细节时, 我们会在公开的漏洞报告中提及您的名字, 除非您要求匿名

## 漏洞回报?

我问问先=-=
